@@ -1,3 +1,4 @@
+
 /* Copyright (C) 1998,1999 Nikos Mavroyanopoulos
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,18 +21,19 @@
 # include <libdefs.h>
 #endif
 
-void Bzero( void *s, int n) {
+void Bzero(void *s, int n)
+{
 #ifdef HAVE_MEMSET
-  memset( s, '\0', n);
+	memset(s, '\0', n);
 #else
 # ifdef HAVE_BZERO
-  bzero( s, n);
+	bzero(s, n);
 # else
-char *stmp=s;
+	char *stmp = s;
 
- for (int i=0;i<n;i++)
-  stmp[i]='\0';
-  
-# endif  
+	for (int i = 0; i < n; i++)
+		stmp[i] = '\0';
+
+# endif
 #endif
 }
