@@ -60,22 +60,30 @@
  * --Nikos
  */
 static unsigned char const k1[16] = {
-        1,  15,  13,  0,  5, 7, 10,  4, 9,  2,  3, 14,  6,  11, 8, 2  };
+	1, 15, 13, 0, 5, 7, 10, 4, 9, 2, 3, 14, 6, 11, 8, 2
+};
 static unsigned char const k2[16] = {
-	13,  11, 4, 1,  3, 15,  5,  9,  0,  10,  14, 7, 6,  8,  2, 12 };
+	13, 11, 4, 1, 3, 15, 5, 9, 0, 10, 14, 7, 6, 8, 2, 12
+};
 static unsigned char const k3[16] = {
-	4,  11,  10, 0,  7,  2, 1,  13,  3, 6, 8,  5, 9,  12,  15,  14 };
+	4, 11, 10, 0, 7, 2, 1, 13, 3, 6, 8, 5, 9, 12, 15, 14
+};
 static unsigned char const k4[16] = {
-	6, 12, 7, 1,  5,  15,  13,  8, 4,  10,  9,  14, 0, 3,  11, 2  };
+	6, 12, 7, 1, 5, 15, 13, 8, 4, 10, 9, 14, 0, 3, 11, 2
+};
 static unsigned char const k5[16] = {
-	7, 13,  10,  1,  0, 8, 9,  15,  14,  4,  6, 12, 11,  2, 5,  3 };
+	7, 13, 10, 1, 0, 8, 9, 15, 14, 4, 6, 12, 11, 2, 5, 3
+};
 static unsigned char const k6[16] = {
-	5,  8, 1, 13,  10,  3,  4,  2,  14, 15,  12,  7, 6,  0,  9, 11 };
+	5, 8, 1, 13, 10, 3, 4, 2, 14, 15, 12, 7, 6, 0, 9, 11
+};
 static unsigned char const k7[16] = {
-	14, 11,  4, 12, 6,  13,  15, 10,  2, 3,  8,  1,  0, 7,  5,  9 };
+	14, 11, 4, 12, 6, 13, 15, 10, 2, 3, 8, 1, 0, 7, 5, 9
+};
 static unsigned char const k8[16] = {
-	4,  10, 9,  2,  13, 8, 0,  14,  6, 11,  1, 12,  7,  15,  5,  3 }; 
-	
+	4, 10, 9, 2, 13, 8, 0, 14, 6, 11, 1, 12, 7, 15, 5, 3
+};
+
 /* Byte-at-a-time substitution boxes */
 static unsigned char k87[256];
 static unsigned char k65[256];
@@ -86,8 +94,7 @@ static unsigned char k21[256];
  * Build byte-at-a-time subtitution tables.
  * This must be called once for global setup.
  */
-void
-_mcrypt_kboxinit(void)
+void _mcrypt_kboxinit(void)
 {
 	int i;
 	for (i = 0; i < 256; i++) {
@@ -107,25 +114,24 @@ _mcrypt_kboxinit(void)
  *
  * This should be inlined for maximum speed
  */
-static word32
-f(word32 x)
+static word32 f(word32 x)
 {
 	/* Do substitutions */
 # if 0
 	/* This is annoyingly slow */
-	x = k8[x>>28 & 15] << 28 | k7[x>>24 & 15] << 24 |
-	    k6[x>>20 & 15] << 20 | k5[x>>16 & 15] << 16 |
-	    k4[x>>12 & 15] << 12 | k3[x>> 8 & 15] <<  8 |
-	    k2[x>> 4 & 15] <<  4 | k1[x     & 15];
+	x = k8[x >> 28 & 15] << 28 | k7[x >> 24 & 15] << 24 |
+	    k6[x >> 20 & 15] << 20 | k5[x >> 16 & 15] << 16 |
+	    k4[x >> 12 & 15] << 12 | k3[x >> 8 & 15] << 8 |
+	    k2[x >> 4 & 15] << 4 | k1[x & 15];
 # else
 	/* This is faster */
-	x = k87[x>>24 & 255] << 24 | k65[x>>16 & 255] << 16 |
-	    k43[x>> 8 & 255] <<  8 | k21[x & 255];
+	x = k87[x >> 24 & 255] << 24 | k65[x >> 16 & 255] << 16 |
+	    k43[x >> 8 & 255] << 8 | k21[x & 255];
 # endif
 
 	/* Rotate left 11 bits */
-	return x<<11 | x>>(32-11);
-	
+	return x << 11 | x >> (32 - 11);
+
 }
 
 /*
@@ -134,88 +140,87 @@ f(word32 x)
  *
  * The keys are defined similarly, with bit 256 being the msb of key[7].
  */
-void
-_mcrypt_gostcrypt(word32 *in, word32 const key[8])
+void _mcrypt_gostcrypt(word32 * in, word32 const key[8])
 {
-	register word32 n1, n2; /* As named in the GOST */
-        word32 s_key[8];
+	register word32 n1, n2;	/* As named in the GOST */
+	word32 s_key[8];
 
 /* Added to make it compatible with bigendian machines 
  * --nikos 
  */
 
 #ifndef WORDS_BIGENDIAN
-        n1=byteswap(in[0]);
-        n2=byteswap(in[1]);
-             s_key[0]=byteswap(key[0]);
-             s_key[1]=byteswap(key[1]);             
-             s_key[2]=byteswap(key[2]);
-             s_key[3]=byteswap(key[3]);
-             s_key[4]=byteswap(key[4]);
-             s_key[5]=byteswap(key[5]);
-             s_key[6]=byteswap(key[6]);             
-             s_key[7]=byteswap(key[7]);
+	n1 = byteswap(in[0]);
+	n2 = byteswap(in[1]);
+	s_key[0] = byteswap(key[0]);
+	s_key[1] = byteswap(key[1]);
+	s_key[2] = byteswap(key[2]);
+	s_key[3] = byteswap(key[3]);
+	s_key[4] = byteswap(key[4]);
+	s_key[5] = byteswap(key[5]);
+	s_key[6] = byteswap(key[6]);
+	s_key[7] = byteswap(key[7]);
 #else
-        n1=in[0];
-        n2=in[1];
-             s_key[0]=(key[0]);
-             s_key[1]=(key[1]);             
-             s_key[2]=(key[2]);
-             s_key[3]=(key[3]);
-             s_key[4]=(key[4]);
-             s_key[5]=(key[5]);
-             s_key[6]=(key[6]);             
-             s_key[7]=(key[7]);
+	n1 = in[0];
+	n2 = in[1];
+	s_key[0] = (key[0]);
+	s_key[1] = (key[1]);
+	s_key[2] = (key[2]);
+	s_key[3] = (key[3]);
+	s_key[4] = (key[4]);
+	s_key[5] = (key[5]);
+	s_key[6] = (key[6]);
+	s_key[7] = (key[7]);
 #endif
-                
+
 	/* Instead of swapping halves, swap names each round */
-	n2 ^= f(n1+s_key[0]);
-	n1 ^= f(n2+s_key[1]);
-	n2 ^= f(n1+s_key[2]);
-	n1 ^= f(n2+s_key[3]);
-	n2 ^= f(n1+s_key[4]);
-	n1 ^= f(n2+s_key[5]);
-	n2 ^= f(n1+s_key[6]);
-	n1 ^= f(n2+s_key[7]);
+	n2 ^= f(n1 + s_key[0]);
+	n1 ^= f(n2 + s_key[1]);
+	n2 ^= f(n1 + s_key[2]);
+	n1 ^= f(n2 + s_key[3]);
+	n2 ^= f(n1 + s_key[4]);
+	n1 ^= f(n2 + s_key[5]);
+	n2 ^= f(n1 + s_key[6]);
+	n1 ^= f(n2 + s_key[7]);
 
-	n2 ^= f(n1+s_key[0]);
-	n1 ^= f(n2+s_key[1]);
-	n2 ^= f(n1+s_key[2]);
-	n1 ^= f(n2+s_key[3]);
-	n2 ^= f(n1+s_key[4]);
-	n1 ^= f(n2+s_key[5]);
-	n2 ^= f(n1+s_key[6]);
-	n1 ^= f(n2+s_key[7]);
+	n2 ^= f(n1 + s_key[0]);
+	n1 ^= f(n2 + s_key[1]);
+	n2 ^= f(n1 + s_key[2]);
+	n1 ^= f(n2 + s_key[3]);
+	n2 ^= f(n1 + s_key[4]);
+	n1 ^= f(n2 + s_key[5]);
+	n2 ^= f(n1 + s_key[6]);
+	n1 ^= f(n2 + s_key[7]);
 
-	n2 ^= f(n1+s_key[0]);
-	n1 ^= f(n2+s_key[1]);
-	n2 ^= f(n1+s_key[2]);
-	n1 ^= f(n2+s_key[3]);
-	n2 ^= f(n1+s_key[4]);
-	n1 ^= f(n2+s_key[5]);
-	n2 ^= f(n1+s_key[6]);
-	n1 ^= f(n2+s_key[7]);
+	n2 ^= f(n1 + s_key[0]);
+	n1 ^= f(n2 + s_key[1]);
+	n2 ^= f(n1 + s_key[2]);
+	n1 ^= f(n2 + s_key[3]);
+	n2 ^= f(n1 + s_key[4]);
+	n1 ^= f(n2 + s_key[5]);
+	n2 ^= f(n1 + s_key[6]);
+	n1 ^= f(n2 + s_key[7]);
 
-	n2 ^= f(n1+s_key[7]);
-	n1 ^= f(n2+s_key[6]);
-	n2 ^= f(n1+s_key[5]);
-	n1 ^= f(n2+s_key[4]);
-	n2 ^= f(n1+s_key[3]);
-	n1 ^= f(n2+s_key[2]);
-	n2 ^= f(n1+s_key[1]);
-	n1 ^= f(n2+s_key[0]);
+	n2 ^= f(n1 + s_key[7]);
+	n1 ^= f(n2 + s_key[6]);
+	n2 ^= f(n1 + s_key[5]);
+	n1 ^= f(n2 + s_key[4]);
+	n2 ^= f(n1 + s_key[3]);
+	n1 ^= f(n2 + s_key[2]);
+	n2 ^= f(n1 + s_key[1]);
+	n1 ^= f(n2 + s_key[0]);
 
 	/* There is no swap after the last round */
 
 #ifndef WORDS_BIGENDIAN
-     in[0]=byteswap(n2);
-     in[1]=byteswap(n1);     
+	in[0] = byteswap(n2);
+	in[1] = byteswap(n1);
 #else
-     in[0]=n2;
-     in[1]=n1;     
+	in[0] = n2;
+	in[1] = n1;
 #endif
 }
-	
+
 
 /*
  * The key schedule is somewhat different for decryption.
@@ -223,80 +228,77 @@ _mcrypt_gostcrypt(word32 *in, word32 const key[8])
  * You could define an expanded key, or just write the code twice,
  * as done here.
  */
-void
-_mcrypt_gostdecrypt(word32 * in, word32 const key[8])
+void _mcrypt_gostdecrypt(word32 * in, word32 const key[8])
 {
-	register word32 n1, n2; /* As named in the GOST */
-        word32 s_key[8]; 
-        
+	register word32 n1, n2;	/* As named in the GOST */
+	word32 s_key[8];
+
 #ifndef WORDS_BIGENDIAN
-	n1=byteswap(in[0]);
-	n2=byteswap(in[1]);
-             s_key[0]=byteswap(key[0]);
-             s_key[1]=byteswap(key[1]);             
-             s_key[2]=byteswap(key[2]);
-             s_key[3]=byteswap(key[3]);
-             s_key[4]=byteswap(key[4]);
-             s_key[5]=byteswap(key[5]);
-             s_key[6]=byteswap(key[6]);             
-             s_key[7]=byteswap(key[7]);
+	n1 = byteswap(in[0]);
+	n2 = byteswap(in[1]);
+	s_key[0] = byteswap(key[0]);
+	s_key[1] = byteswap(key[1]);
+	s_key[2] = byteswap(key[2]);
+	s_key[3] = byteswap(key[3]);
+	s_key[4] = byteswap(key[4]);
+	s_key[5] = byteswap(key[5]);
+	s_key[6] = byteswap(key[6]);
+	s_key[7] = byteswap(key[7]);
 #else
-	n1=in[0];
-	n2=in[1];
-             s_key[0]=(key[0]);
-             s_key[1]=(key[1]);             
-             s_key[2]=(key[2]);
-             s_key[3]=(key[3]);
-             s_key[4]=(key[4]);
-             s_key[5]=(key[5]);
-             s_key[6]=(key[6]);             
-             s_key[7]=(key[7]);
+	n1 = in[0];
+	n2 = in[1];
+	s_key[0] = (key[0]);
+	s_key[1] = (key[1]);
+	s_key[2] = (key[2]);
+	s_key[3] = (key[3]);
+	s_key[4] = (key[4]);
+	s_key[5] = (key[5]);
+	s_key[6] = (key[6]);
+	s_key[7] = (key[7]);
 #endif
 
-	n2 ^= f(n1+s_key[0]);
-	n1 ^= f(n2+s_key[1]);
-	n2 ^= f(n1+s_key[2]);
-	n1 ^= f(n2+s_key[3]);
-	n2 ^= f(n1+s_key[4]);
-	n1 ^= f(n2+s_key[5]);
-	n2 ^= f(n1+s_key[6]);
-	n1 ^= f(n2+s_key[7]);
+	n2 ^= f(n1 + s_key[0]);
+	n1 ^= f(n2 + s_key[1]);
+	n2 ^= f(n1 + s_key[2]);
+	n1 ^= f(n2 + s_key[3]);
+	n2 ^= f(n1 + s_key[4]);
+	n1 ^= f(n2 + s_key[5]);
+	n2 ^= f(n1 + s_key[6]);
+	n1 ^= f(n2 + s_key[7]);
 
-	n2 ^= f(n1+s_key[7]);
-	n1 ^= f(n2+s_key[6]);
-	n2 ^= f(n1+s_key[5]);
-	n1 ^= f(n2+s_key[4]);
-	n2 ^= f(n1+s_key[3]);
-	n1 ^= f(n2+s_key[2]);
-	n2 ^= f(n1+s_key[1]);
-	n1 ^= f(n2+s_key[0]);
+	n2 ^= f(n1 + s_key[7]);
+	n1 ^= f(n2 + s_key[6]);
+	n2 ^= f(n1 + s_key[5]);
+	n1 ^= f(n2 + s_key[4]);
+	n2 ^= f(n1 + s_key[3]);
+	n1 ^= f(n2 + s_key[2]);
+	n2 ^= f(n1 + s_key[1]);
+	n1 ^= f(n2 + s_key[0]);
 
-	n2 ^= f(n1+s_key[7]);
-	n1 ^= f(n2+s_key[6]);
-	n2 ^= f(n1+s_key[5]);
-	n1 ^= f(n2+s_key[4]);
-	n2 ^= f(n1+s_key[3]);
-	n1 ^= f(n2+s_key[2]);
-	n2 ^= f(n1+s_key[1]);
-	n1 ^= f(n2+s_key[0]);
+	n2 ^= f(n1 + s_key[7]);
+	n1 ^= f(n2 + s_key[6]);
+	n2 ^= f(n1 + s_key[5]);
+	n1 ^= f(n2 + s_key[4]);
+	n2 ^= f(n1 + s_key[3]);
+	n1 ^= f(n2 + s_key[2]);
+	n2 ^= f(n1 + s_key[1]);
+	n1 ^= f(n2 + s_key[0]);
 
-	n2 ^= f(n1+s_key[7]);
-	n1 ^= f(n2+s_key[6]);
-	n2 ^= f(n1+s_key[5]);
-	n1 ^= f(n2+s_key[4]);
-	n2 ^= f(n1+s_key[3]);
-	n1 ^= f(n2+s_key[2]);
-	n2 ^= f(n1+s_key[1]);
-	n1 ^= f(n2+s_key[0]);
+	n2 ^= f(n1 + s_key[7]);
+	n1 ^= f(n2 + s_key[6]);
+	n2 ^= f(n1 + s_key[5]);
+	n1 ^= f(n2 + s_key[4]);
+	n2 ^= f(n1 + s_key[3]);
+	n1 ^= f(n2 + s_key[2]);
+	n2 ^= f(n1 + s_key[1]);
+	n1 ^= f(n2 + s_key[0]);
 
 #ifndef WORDS_BIGENDIAN
-     in[0]=byteswap(n2);
-     in[1]=byteswap(n1);
+	in[0] = byteswap(n2);
+	in[1] = byteswap(n1);
 #else
-     in[0]=n2;
-     in[1]=n1;
-#endif 
+	in[0] = n2;
+	in[1] = n1;
+#endif
 
 }
-
-
