@@ -26,7 +26,7 @@
 #define SAFER128 7
 #define CAST128 8
 #define TEAN 9
-#define RC2 11
+#define RC2_1024 11
 #define TWOFISH128 10
 #define TWOFISH192 12
 #define TWOFISH256 13
@@ -36,8 +36,22 @@
 #define CAST256 17
 #define SAFERPLUS 18
 #define LOKI97 19
-#define RC6 100
+#define SERPENT128 20
+#define SERPENT192 21
+#define SERPENT256 22
+#define RIJNDAEL128 23
+#define RIJNDAEL192 24
+#define RIJNDAEL256 25
+#define RC2_256 26
+#define RC2_128 27
+
+#define RC6_256 100
 #define IDEA 101
+#define RC6_128 102
+#define RC6_192 103
+#define MARS128 104
+#define MARS192 105
+#define MARS256 106
 
 #define CBC 0
 #define ECB 1
