@@ -28,7 +28,6 @@
 #include <des.h>
 #include <safer.h>
 #include <tean.h>
-#include <aes.h>
 #include <xmemory.h>
 #include <rc2.h>
 #include <rc6.h>
@@ -36,6 +35,7 @@
 #include <sha1.h>
 #include <md5.h>
 #include <loki97.h>
+#include <rijndael.h>
 
 int mcrypt_get_block_size(int algorithm)
 {
@@ -52,7 +52,9 @@ int mcrypt_get_block_size(int algorithm)
 	case SAFER128:
 	case CAST128:
 	case TEAN:
-	case RC2:
+	case RC2_1024:
+	case RC2_128:
+	case RC2_256:
 		return 8;
 		break;
 
@@ -61,11 +63,14 @@ int mcrypt_get_block_size(int algorithm)
 		return 8;
 		break;
 
-	case RC6:
-		return 16;
-		break;
+	case RC6_256:
+	case RC6_192:
+	case RC6_128:
 #endif
 
+	case RIJNDAEL128:
+	case RIJNDAEL192:
+	case RIJNDAEL256:
 	case LOKI97:
 	case SAFERPLUS:
 	case CAST256:
@@ -108,26 +113,51 @@ int mcrypt_get_key_size(int algorithm)
 	case SAFERPLUS:
 		return 32;
 		break;
-		
+
 	case BLOWFISH192:
 		return 24;
 		break;
-		
+
 	case BLOWFISH128:
 		return 16;
 		break;
 
-	case RC2:
+	case RC2_1024:
 		return 128;
 		break;
 
-#ifdef NON_FREE
-	case RC6:
-//		return RC6_BKEY;	/* 32 */
+	case RC2_128:
+		return 16;
+		break;
+
+	case RC2_256:
 		return 32;
 		break;
+
+#ifdef NON_FREE
+
+	case RC6_128:
+		return 16;
+		break;
+	case RC6_192:
+		return 24;
+		break;
+	case RC6_256:
+		return 32;
+		break;
+
 #endif
 
+	case RIJNDAEL128:
+		return 16;
+		break;
+	case RIJNDAEL192:
+		return 24;
+		break;
+	case RIJNDAEL256:
+		return 32;
+		break;
+
 	case TWOFISH192:
 		return 24;
 		break;
@@ -174,8 +204,18 @@ char *get_algorithms_name(int algorithm)
 		return x;
 		break;
 
-	case RC2:
-		strcpy(x, "RC2");
+	case RC2_1024:
+		strcpy(x, "RC2-1024");
+		return x;
+		break;
+
+	case RC2_256:
+		strcpy(x, "RC2-256");
+		return x;
+		break;
+
+	case RC2_128:
+		strcpy(x, "RC2-128");
 		return x;
 		break;
 
@@ -185,12 +225,34 @@ char *get_algorithms_name(int algorithm)
 		return x;
 		break;
 
-	case RC6:
-		strcpy(x, "RC6");
+	case RC6_128:
+		strcpy(x, "RC6-128");
 		return x;
 		break;
+	case RC6_192:
+		strcpy(x, "RC6-192");
+		return x;
+		break;
+	case RC6_256:
+		strcpy(x, "RC6-256");
+		return x;
+		break;
+
 #endif
 
+	case RIJNDAEL128:
+		strcpy(x, "RIJNDAEL-128");
+		return x;
+		break;
+	case RIJNDAEL192:
+		strcpy(x, "RIJNDAEL-192");
+		return x;
+		break;
+	case RIJNDAEL256:
+		strcpy(x, "RIJNDAEL-256");
+		return x;
+		break;
+
 	case TripleDES:
 		strcpy(x, "3DES");
 		return x;
@@ -224,7 +286,7 @@ char *get_algorithms_name(int algorithm)
 	case CAST256:
 		strcpy(x, "CAST-256");
 		return x;
-		break;	
+		break;
 	case TWOFISH128:
 		strcpy(x, "Twofish-128");
 		return x;
@@ -247,7 +309,7 @@ char *get_algorithms_name(int algorithm)
 		strcpy(x, "LOKI97");
 		return x;
 		break;
-		
+
 	case SAFERPLUS:
 		strcpy(x, "SAFER+");
 		return x;
@@ -281,15 +343,19 @@ int is_ok_algorithm(int algorithm)
 
 	switch (algorithm) {
 	case DES:
-	case RC2:
+	case RC2_128:
+	case RC2_1024:
+	case RC2_256:
 #ifdef NON_FREE
 	case IDEA:
-	case RC6:
+	case RC6_128:
+	case RC6_192:
+	case RC6_256:
 #endif
 	case TripleDES:
 	case ThreeWAY:
 	case BLOWFISH448:
-	case BLOWFISH256:	
+	case BLOWFISH256:
 	case BLOWFISH192:
 	case BLOWFISH128:
 	case CAST256:
@@ -302,6 +368,10 @@ int is_ok_algorithm(int algorithm)
 	case CAST128:
 	case TEAN:
 	case SAFERPLUS:
+	case RIJNDAEL128:
+	case RIJNDAEL192:
+	case RIJNDAEL256:
+
 	case LOKI97:
 		return 0;
 		break;
@@ -367,15 +437,15 @@ char *get_modes_name(int mode)
 		return x;
 		break;
 	default:
-	        return NULL;
+		return NULL;
 
-        }
+	}
 }
 
 
 /* Key generation using sha1 */
 void gen_key_sha1(void *keyword, void *salt, int salt_size, int key_size,
-	     unsigned char *password, int plen)
+		  unsigned char *password, int plen)
 {
 	unsigned char key[MAX_KEY_LEN];
 	SHA1_CTX ctx;
@@ -411,7 +481,7 @@ void gen_key_sha1(void *keyword, void *salt, int salt_size, int key_size,
 
 
 void gen_key_md5(void *keyword, void *salt, int salt_size, int key_size,
-	     unsigned char *password, int plen)
+		 unsigned char *password, int plen)
 {
 	unsigned char key[MAX_KEY_LEN];
 	MD5_CTX ctx;
