@@ -25,12 +25,12 @@
 void _mcrypt_rc2_keyschedule(word16 * xkey, const word8 * key,
 			     unsigned int len)
 {
-	unsigned int j,i;
-	word8 *xkey_p = (void *) xkey;
+	unsigned int j;
+	word8 *xkey_p=(void*)xkey;
+	int i;
 
 	/* 256-entry permutation table, probably derived somehow from pi */
-	static const word8 permute[256] =
-	{
+	static const word8 permute[256] = {
 		217, 120, 249, 196, 25, 221, 181, 237, 40, 233, 253, 121,
 		74, 160, 216, 157,
 		198, 126, 55, 131, 43, 118, 83, 142, 98, 76, 100, 136,
@@ -72,7 +72,8 @@ void _mcrypt_rc2_keyschedule(word16 * xkey, const word8 * key,
 	/* Phase 1: Expand input key to 128 bytes */
 
 	for (j = len; j < 128; j++) {
-		xkey_p[j] = permute[(xkey_p[j - len] + xkey_p[j - 1]) % 256];
+		xkey_p[j] =
+		    permute[(xkey_p[j - len] + xkey_p[j - 1]) % 256];
 	}
 
 	xkey_p[0] = permute[xkey_p[0]];
@@ -81,12 +82,11 @@ void _mcrypt_rc2_keyschedule(word16 * xkey, const word8 * key,
 	/* stripped */
 
 	/* Phase 3 - copy to xkey in little-endian order */
-
-#ifdef WORDS_BIGENDIAN
-	for (i = 0; i < 64; i++) {
-		xkey[i] = byteswap_16(xkey[i]);
-	}
-#endif
+	i = 63;
+	do {
+		xkey[i] =  xkey_p[2*i] +
+		          (xkey_p[2*i+1] << 8);
+	} while (i--);
 
 }
 
@@ -99,23 +99,30 @@ void _mcrypt_rc2_encrypt(const word16 * xkey, word16 * plain)
 {
 	word16 x3, x2, x1, x0, i;
 
+#ifdef WORDS_BIGENDIAN
+	x3 = byteswap_16(plain[3]);
+	x2 = byteswap_16(plain[2]);
+	x1 = byteswap_16(plain[1]);
+	x0 = byteswap_16(plain[0]);
+#else
 	x3 = plain[3];
 	x2 = plain[2];
 	x1 = plain[1];
 	x0 = plain[0];
+#endif
 
 	for (i = 0; i < 16; i++) {
 		x0 += (x1 & ~x3) + (x2 & x3) + xkey[4 * i + 0];
-		x0 = (x0 << 1) + (x0 >> 15 & 1);
+		x0 = rotl16(x0, 1);
 
 		x1 += (x2 & ~x0) + (x3 & x0) + xkey[4 * i + 1];
-		x1 = (x1 << 2) + (x1 >> 14 & 3);
+		x1 = rotl16(x1, 2);
 
 		x2 += (x3 & ~x1) + (x0 & x1) + xkey[4 * i + 2];
-		x2 = (x2 << 3) + (x2 >> 13 & 7);
+		x2 = rotl16(x2, 3);
 
 		x3 += (x0 & ~x2) + (x1 & x2) + xkey[4 * i + 3];
-		x3 = (x3 << 5) + (x3 >> 11 & 31);
+		x3 = rotl16(x3, 5);
 
 		if (i == 4 || i == 10) {
 			x0 += xkey[x3 & 63];
@@ -125,10 +132,19 @@ void _mcrypt_rc2_encrypt(const word16 * xkey, word16 * plain)
 		}
 	}
 
-	plain[0] = x0;
-	plain[1] = x1;
-	plain[2] = x2;
-	plain[3] = x3;
+#ifdef WORDS_BIGENDIAN
+	plain[0] = byteswap_16(x0);
+	plain[1] = byteswap_16(x1);
+	plain[2] = byteswap_16(x2);
+	plain[3] = byteswap_16(x3);
+#else
+	plain[0] = (x0);
+	plain[1] = (x1);
+	plain[2] = (x2);
+	plain[3] = (x3);
+
+#endif
+
 }
 
 /**********************************************************************\
@@ -139,27 +155,31 @@ void _mcrypt_rc2_decrypt(const word16 * xkey, word16 * plain)
 {
 	word16 x3, x2, x1, x0, i;
 
+#ifndef WORDS_BIGENDIAN
 	x3 = plain[3];
 	x2 = plain[2];
 	x1 = plain[1];
 	x0 = plain[0];
+#else
+	x3 = byteswap_16(plain[3]);
+	x2 = byteswap_16(plain[2]);
+	x1 = byteswap_16(plain[1]);
+	x0 = byteswap_16(plain[0]);
+#endif
+
 
 	i = 15;
 	do {
-		x3 &= 65535;
-		x3 = (x3 << 11) + (x3 >> 5);
+		x3 = rotr16(x3, 5);
 		x3 -= (x0 & ~x2) + (x1 & x2) + xkey[4 * i + 3];
 
-		x2 &= 65535;
-		x2 = (x2 << 13) + (x2 >> 3);
+		x2 = rotr16(x2, 3);
 		x2 -= (x3 & ~x1) + (x0 & x1) + xkey[4 * i + 2];
 
-		x1 &= 65535;
-		x1 = (x1 << 14) + (x1 >> 2);
+		x1 = rotr16(x1, 2);
 		x1 -= (x2 & ~x0) + (x3 & x0) + xkey[4 * i + 1];
 
-		x0 &= 65535;
-		x0 = (x0 << 15) + (x0 >> 1);
+		x0 = rotr16(x0, 1);
 		x0 -= (x1 & ~x3) + (x2 & x3) + xkey[4 * i + 0];
 
 		if (i == 5 || i == 11) {
@@ -170,8 +190,15 @@ void _mcrypt_rc2_decrypt(const word16 * xkey, word16 * plain)
 		}
 	} while (i--);
 
+#ifdef WORDS_BIGENDIAN
+	plain[0] = byteswap_16(x0);
+	plain[1] = byteswap_16(x1);
+	plain[2] = byteswap_16(x2);
+	plain[3] = byteswap_16(x3);
+#else
 	plain[0] = x0;
 	plain[1] = x1;
 	plain[2] = x2;
 	plain[3] = x3;
+#endif
 }
