@@ -1,3 +1,4 @@
+
 /* Copyright (C) 1998,1999 Nikos Mavroyanopoulos
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,9 +27,11 @@
 #endif
 
 #ifdef HAVE_MLOCK
-void LOCKMEM( void* x, size_t size) {
- mlock(x,size);
+void LOCKMEM(void *x, size_t size)
+{
+	mlock(x, size);
 }
+
 # define UNLOCKMEM(x,y) munlock(x,y)
 #else
 # define LOCKMEM(x,y)
@@ -40,87 +43,85 @@ void LOCKMEM( void* x, size_t size) {
 
 /* memory allocation */
 
-void *mxmalloc(size_t size) {
-char *x;
+void *mxmalloc(size_t size)
+{
+	char *x;
 
- x=malloc(size);
- 
- if (x!=NULL) {
-  LOCKMEM(x,size);
-  return x;
- }
- else {
-  sleep(1);
-  x=malloc(size);
-  if (x!=NULL) {
-   LOCKMEM(x,size);
-   return x;
-  }
-  else {
-   fprintf(stderr, ("Cannot allocate memory\n"));
-   exit(-1);
-  }
- }
+	x = malloc(size);
+
+	if (x != NULL) {
+		LOCKMEM(x, size);
+		return x;
+	} else {
+		sleep(1);
+		x = malloc(size);
+		if (x != NULL) {
+			LOCKMEM(x, size);
+			return x;
+		} else {
+			fprintf(stderr, ("Cannot allocate memory\n"));
+			exit(-1);
+		}
+	}
 /* Not really needed */
- return x;
+	return x;
 }
 
-void *mxcalloc(size_t nmemb, size_t size) {
-char *x;
+void *mxcalloc(size_t nmemb, size_t size)
+{
+	char *x;
 
- x=calloc(nmemb, size);
- if (x!=NULL) {
-    return x;
-    LOCKMEM(x,size);
- }
- else {
-  sleep(1);
-  x=calloc(nmemb, size);
-  if (x!=NULL) {
-    LOCKMEM(x,size);
-    return x;
-  }
-  else {
-   fprintf(stderr, ("Cannot allocate memory\n"));
-   exit(-1);
-  }
- }
+	x = calloc(nmemb, size);
+	if (x != NULL) {
+		return x;
+		LOCKMEM(x, size);
+	} else {
+		sleep(1);
+		x = calloc(nmemb, size);
+		if (x != NULL) {
+			LOCKMEM(x, size);
+			return x;
+		} else {
+			fprintf(stderr, ("Cannot allocate memory\n"));
+			exit(-1);
+		}
+	}
 /* Not really needed */
- return x;
+	return x;
 
 }
 
-void *mxrealloc(void *ptr, size_t size) {
-char *x;
+void *mxrealloc(void *ptr, size_t size)
+{
+	char *x;
 
- x=realloc(ptr, size);
- if (x!=NULL) {
-    LOCKMEM(x,size);
-    return x;
- }
- else {
-  sleep(1);
-  x=realloc(ptr, size);
-  if (x!=NULL) {
-    LOCKMEM(x,size);
-    return x;
-  }
-  else {
-   fprintf(stderr, ("Cannot allocate memory\n"));
-   exit(-1);
-  }
- }
+	x = realloc(ptr, size);
+	if (x != NULL) {
+		LOCKMEM(x, size);
+		return x;
+	} else {
+		sleep(1);
+		x = realloc(ptr, size);
+		if (x != NULL) {
+			LOCKMEM(x, size);
+			return x;
+		} else {
+			fprintf(stderr, ("Cannot allocate memory\n"));
+			exit(-1);
+		}
+	}
 /* Not really needed */
 /* Just for some compilers which complain */
- return x;
+	return x;
 
 }
 
 
-void mxfree(void *ptr, size_t size) {
+void mxfree(void *ptr, size_t size)
+{
+
+	Bzero(ptr, size);
+	UNLOCKMEM(ptr, size);
+	free(ptr);
 
-  Bzero( ptr, size);
-  UNLOCKMEM(ptr ,size);
-  free(ptr);
-          
 }
